@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2016, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,12 +17,14 @@
 
 //======================================================================
 // define
-#define IUTEST_VER          0x01150200u //!< iutest version 1.15.2.0
+#define IUTEST_VER          0x01160100u //!< iutest version 1.16.1.0
 #define IUTEST_MAJORVER     0x01u       //!< Major Version
-#define IUTEST_MINORVER     0x15u       //!< Minor Version
-#define IUTEST_BUILD        0x02u       //!< Build
+#define IUTEST_MINORVER     0x16u       //!< Minor Version
+#define IUTEST_MICROVER     0x01u       //!< Micro Version
 #define IUTEST_REVISION     0x00u       //!< Revision
 
+#define IUTEST_BUILD        IUTEST_MICROVER //!< @deprecated
+
 /**
  * @mainpage
  * @sa  @b  ProjectHome \n
@@ -31,7 +33,7 @@
  *          google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
  *
  * @par     copyright
- * Copyright (C) 2011-2016, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
  * This software is released under the new BSD License.
  *
  * @par     LICENSE
@@ -116,6 +118,19 @@
  * @page    CHANGELOG   変更履歴
  * @par     Changes
  <ul>
+  <li>v1.16.1.0
+    <ul>
+      <li>IUTEST_BUILD を非推奨に変更し、IUTEST_MICROVER を追加</li>
+      <li>XML_OUTPUT_FILE 環境変数に対応</li>
+    </ul>
+  </li>
+  <li>v1.16.0.0
+    <ul>
+      <li>iuwandbox で複数ソースファイルに対応</li>
+      <li>例外アサーションで構造化例外（SEH）もキャッチできるように対応</li>
+      <li>--iutest_filter のルールを Google Test 互換に修正</li>
+    </ul>
+  </li>
   <li>v1.15.2.0
     <ul>
       <li>IUTEST_TYPED_TEST_P に対して friend できるように IUTEST_FRIEND_TYPED_TEST_P_DECLARATION/IUTEST_FRIEND_TYPED_TEST_P を追加</li>
